@@ -1,21 +1,20 @@
 #!/usr/bin/env python
 #
-# Copyright (C) 2005, 2006, 2008 Nicolas Burrus
 # This file is part of Tidydoc.
+# Copyright (C) 2005, 2008, 2009 Nicolas Burrus
 #
-# Tidydoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
 #
-# Tidydoc is distributed in the hope that it will be useful,
+# This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with Foobar; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os, re, sys
 
@@ -36,9 +35,13 @@ def extract_initials(name):
   return s
 
 def generate_bibtex_entry(doc):
-  bibtex_type = doc.content['bibtex_type'][0]
-  if len(bibtex_type) == 0:
-    bibtex_type = "misc"
+  bibtex = doc.content['bibtex'][0]
+  if (len(bibtex) != 0):
+    lines = bibtex.splitlines()
+    for i in range(1, len(lines)-1):
+      lines[i] = "  " + lines[i].lstrip()
+    return "\n".join(lines)
+  bibtex_type = "misc"
   authors = [extract_initials(x) for x in doc.content['author']]
   authors = " and ".join(authors)
   title = doc.content['title'][0]
@@ -50,15 +53,11 @@ def generate_bibtex_entry(doc):
   m = re.match('.*(\d\d\d\d).*', doc.content['date'][0])
   if m:
     year = m.group(1)
-  bibfields = ""
-  if len(doc.content['bibtex_fields'][0]) > 0:
-    bibfields = doc.content['bibtex_fields'][0].split("\n")
-    bibfields = "\n" + ",\n".join([("  " + x) for x in bibfields])
   return \
 ("""
 @%(bibtex_type)s{%(name)s,
   author = {%(authors)s},
-  title = {%(title)s}, %(bibfields)s,
+  title = {%(title)s},
   year = {%(year)s},
 }
 """ % locals())
