@@ -1,27 +1,26 @@
 #!/usr/bin/env python
 #
-# Copyright (C) 2005, 2006, 2008, 2009 Nicolas Burrus
 # This file is part of Tidydoc.
+# Copyright (C) 2005, 2008, 2009 Nicolas Burrus
 #
-# Tidydoc is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
 #
-# Tidydoc is distributed in the hope that it will be useful,
+# This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with Foobar; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from glob import glob
 import os, re, sys
 
 import td_tools
-from td_tools import is_more_recent
+from td_tools import is_more_recent, rel_path
 import td_config
 import td_debug
 import td_xml
@@ -93,6 +92,15 @@ def nb_docs(doctree):
     n += nb_docs(subdir)
   return n
 
+def walk_to_category(doctree, category):
+  if rel_path(doctree.path) == category:
+    return doctree
+  for subdir in doctree.subdirs:
+    result = walk_to_category(subdir, category)
+    if result:
+      return result
+  return None
+
 if __name__ == '__main__':
   td_config.read_config()
   doctree = build(config['input_path'])
